Search.setIndex({objects:{},terms:{elif:[],run_local_serv:3,help:3,just:1,branch:3,runner:3,concurr:3,runserv:3,self_upgrad:3,follow:3,find:3,celeri:3,onli:3,project_us:3,img:1,make_releas:[],activ:3,either:3,custom_migr:3,requir:[2,3],els:3,project_id:3,local:3,app:[1,3],kick:3,build:3,bin:3,celeryd:3,sourc:3,everi:3,whichev:4,get:1,python:3,auto:3,util:[0,2],tabl:2,"new":[],fab:[2,3],docs_dir:3,restart:3,like:4,name:3,slugifi:0,server:3,collect:3,gravatar:[2,1],avatar:1,quick:[2,4],through:4,manag:3,view:3,set:3,sync:3,ensur:[],design:3,log_loc:3,pass:3,noinput:3,syncdb:3,email_address:1,librari:1,out:3,virtualenv:3,index:2,what:3,sync_db:3,kick_apach:3,content:2,version:3,print:3,"import":0,prod:3,refer:[2,3],run:3,migrat:3,usag:[0,1,2],broker:3,fabfil:3,host:3,django_env:3,releas:[],webapp:3,slug:[0,2],log:3,src:1,search:2,apache_bin_dir:3,ahead:0,build_migr:3,page:2,instanc:3,view_log:3,apache2:3,schemamigr:3,com:[3,4],produc:1,first:3,origin:3,apach:3,modul:2,docs_stat:3,comit:3,height:1,pip_install_req:3,right:3,been:[],org:3,contrib:[2,1],instal:[2,1,3,4],txt:3,your:3,size:1,given:3,collect_stat:3,from:0,fabric:3,width:1,virtual_dir:3,add:1,wrapper:1,copy_stat:[],start:[2,3,4],call:3,includ:[0,1,3],get_gravatar:1,master:4,git_repo:3,dstegelman:[3,4],production_branch:3,hadrian:[0,1,2,3,4],unique_slugifi:0,"function":3,asset:3,imag:1,specifi:3,upgrad:3,provid:3,collectstat:3,templat:1,project_host:3,git:[3,4],grace:[],must:3,info:3,pull:3,none:3,made:[],remot:3,checkout:3,setup:[2,1],uniqu:0,cat:3,project:3,url:1,can:4,"static":3,fetch:3,def:3,file:3,helper:3,process:3,sudo:3,indic:2,error_django_env:3,packag:[0,4],pip:[3,4],tag:[1,3],caution:3,set_host:[],conf:[2,3],deploy_us:3,need:3,border:1,field_to_slugifi:0,develop:3,welcom:2,titl:[],self:0,custom:3,get_code_releas:3,webfact:3,take:3,env:3,test:3,environ:[2,3],you:4,document:2,singl:3,complet:3,variabl:[2,3],product:3,deploy:3,run_loc:3,fotochest:3,befor:3,user:3,deploi:3,mai:3,alpha:3,"class":1,get_code_latest:3,bitbucket:3,github:[3,4],static_dir:3,directori:3,release_tag:3,project_virtu:3,django:3,which:1,declar:3,command:[2,3],thi:3,start_celeri:3,push:[],built:1,slug_field:0,egg:[3,4],make:[]},objtypes:{},titles:["Hadrian.Utils.Slugs","Hadrian.Contrib.Gravatar","Welcome to Hadrian&#8217;s documentation!","Hadrian.Conf.Fab","Quick Start"],objnames:{},filenames:["utils/slugs","contrib/gravatar/quick_start","index","conf/fabric","quick_start"]})